(examples_link)=

# Examples

Example files for **SHRY** are found at
https://github.com/shry-project/SHRY/tree/main/examples.

The `examples/` directory contains several examples.

- `example1.py`: Basic enumeration and CIF output.
- `example2.py`: Comparison with enumlib.
- `example3.py`: LabeledStructure and label-based substitutions.
- `example4a.py`/`4b.py`: Caching pattern generation.
- `example5.py`: Generating ASE Atoms.
- `example6.py`: Ranking by Ewald energy.
- `example7.py`: Highest symmetry structures.
- `example8.py`: Merge multiple Wyckoff labels.
